ActiveState

Enum ActiveState 

enum ActiveState {
    Disabled,
    Enabled {
        storage: Storage,
        tx_downloads: Pin<Box<Downloads<Timeout<Buffer<BoxService<Request, Response, BoxError>, Request>>, Timeout<Buffer<BoxService<Request, Response, TransactionError>, Request>>, Buffer<BoxService<Request, Response, BoxError>, Request>>>>,
        last_seen_tip_hash: Hash,
    },
}
The state of the mempool.

Indicates whether it is enabled or disabled and, if enabled, contains the necessary data to run it.

Variants



Disabled

The Mempool is disabled.



Enabled

The Mempool is enabled.

Fields

storage: Storage

The Mempool storage itself.

Correctness

Only components internal to the Mempool struct are allowed to inject transactions into storage, as transactions must be verified beforehand.

tx_downloads: Pin<Box<Downloads<Timeout<Buffer<BoxService<Request, Response, BoxError>, Request>>, Timeout<Buffer<BoxService<Request, Response, TransactionError>, Request>>, Buffer<BoxService<Request, Response, BoxError>, Request>>>>

The transaction download and verify stream.

last_seen_tip_hash: Hash

Last seen chain tip hash that mempool transactions have been verified against.

In some tests, this is initialized to the latest chain tip, then updated in poll_ready() before each request.

Implementations

Source

impl ActiveState

fn take(&mut self) -> Self

Returns the current state, leaving Self::Disabled in its place.

fn transaction_retry_requests(&self) -> Vec<Gossip>

Returns a list of requests that will retry every stored and pending transaction.

fn queued_transaction_count(&self) -> usize

Returns the number of pending transactions waiting for download or verify, or zero if the mempool is disabled.

fn transaction_count(&self) -> usize

Returns the number of transactions in storage, or zero if the mempool is disabled.

fn total_cost(&self) -> u64

Returns the cost of the transactions in the mempool, according to ZIP-401. Returns zero if the mempool is disabled.

pub fn total_serialized_size(&self) -> usize

Returns the total serialized size of the verified transactions in the set, or zero if the mempool is disabled.

See Storage::total_serialized_size() for details.

fn rejected_transaction_count(&mut self) -> usize

Returns the number of rejected transaction hashes in storage, or zero if the mempool is disabled.