pub enum MempoolError {
StorageExactTip(ExactTipRejectionError),
StorageEffectsTip(SameEffectsTipRejectionError),
StorageEffectsChain(SameEffectsChainRejectionError),
InMempool,
AlreadyQueued,
FullQueue,
Disabled,
NonStandardTransaction(NonStandardTransactionError),
}Expand description
Mempool errors.
Variants
StorageExactTip(ExactTipRejectionError)
Transaction rejected based on its authorizing data (scripts, proofs, signatures). The rejection is valid for the current chain tip.
See ExactTipRejectionError for more details.
Note that the mempool caches this error. See super::storage::Storage
for more details.
StorageEffectsTip(SameEffectsTipRejectionError)
Transaction rejected based on its effects (spends, outputs, transaction header). The rejection is valid for the current chain tip.
See SameEffectsTipRejectionError for more details.
Note that the mempool caches this error. See super::storage::Storage
for more details.
StorageEffectsChain(SameEffectsChainRejectionError)
Transaction rejected based on its effects (spends, outputs, transaction header). The rejection is valid while the current chain continues to grow.
See SameEffectsChainRejectionError for more details.
Note that the mempool caches this error. See super::storage::Storage
for more details.
InMempool
Transaction rejected because the mempool already contains another transaction with the same hash.
AlreadyQueued
The transaction hash is already queued, so this request was ignored.
Another peer has already gossiped the same hash to us, or the mempool crawler has fetched it.
FullQueue
The queue is at capacity, so this request was ignored.
The mempool crawler should discover this transaction later. If it is mined into a block, it will be downloaded by the syncer, or the inbound block downloader.
The queue’s capacity is super::downloads::MAX_INBOUND_CONCURRENCY.
Disabled
The mempool is not enabled yet.
Zebra enables the mempool when it is at the chain tip.
NonStandardTransaction(NonStandardTransactionError)
The transaction is non-standard.