pub enum SameEffectsChainRejectionError {
Expired,
DuplicateSpend,
Mined,
RandomlyEvicted,
}Expand description
Transactions rejected based only on their effects (spends, outputs, transaction header). These rejections are valid while the current chain continues to grow.
Rollbacks and network upgrades clear these rejections, because they can lower the tip height, or change the consensus rules.
Variants
Expired
DuplicateSpend
Mined
RandomlyEvicted
Otherwise valid transaction removed from mempool due to ZIP-401 random eviction.
Consensus rule:
The txid (rather than the wtxid …) is used even for version 5 transactions