pub struct Mempool {Show 15 fields
config: Config,
active_state: ActiveState,
sync_status: SyncStatus,
debug_enable_at_height: Option<Height>,
latest_chain_tip: LatestChainTip,
chain_tip_change: ChainTipChange,
outbound: Buffer<BoxService<Request, Response, BoxError>, Request>,
state: Buffer<BoxService<Request, Response, BoxError>, Request>,
tx_verifier: Buffer<BoxService<Request, Response, TransactionError>, Request>,
transaction_sender: Sender<MempoolChange>,
misbehavior_sender: Sender<(PeerSocketAddr, u32)>,
queued_count_bar: Option<Tx>,
transaction_count_bar: Option<Tx>,
transaction_cost_bar: Option<Tx>,
rejected_count_bar: Option<Tx>,
}Expand description
Mempool async management and query service.
The mempool is the set of all verified transactions that this node is aware of that have yet to be confirmed by the Zcash network. A transaction is confirmed when it has been included in a block (‘mined’).
Fields
config: ConfigThe configurable options for the mempool, persisted between states.
active_state: ActiveStateThe state of the mempool.
sync_status: SyncStatusAllows checking if we are near the tip to enable/disable the mempool.
debug_enable_at_height: Option<Height>If the state’s best chain tip has reached this height, always enable the mempool.
latest_chain_tip: LatestChainTipAllows efficient access to the best tip of the blockchain.
chain_tip_change: ChainTipChangeAllows the detection of newly added chain tip blocks, and chain tip resets.
outbound: Buffer<BoxService<Request, Response, BoxError>, Request>Handle to the outbound service. Used to construct the transaction downloader.
state: Buffer<BoxService<Request, Response, BoxError>, Request>Handle to the state service. Used to construct the transaction downloader.
tx_verifier: Buffer<BoxService<Request, Response, TransactionError>, Request>Handle to the transaction verifier service. Used to construct the transaction downloader.
transaction_sender: Sender<MempoolChange>Sender part of a gossip transactions channel. Used to broadcast transaction ids to peers.
misbehavior_sender: Sender<(PeerSocketAddr, u32)>Sender for reporting peer addresses that advertised unexpectedly invalid transactions.
queued_count_bar: Option<Tx>Queued transactions pending download or verification transmitter. Only displayed after the mempool’s first activation.
transaction_count_bar: Option<Tx>Number of mempool transactions transmitter. Only displayed after the mempool’s first activation.
transaction_cost_bar: Option<Tx>Mempool transaction cost transmitter. Only displayed after the mempool’s first activation.
rejected_count_bar: Option<Tx>Rejected transactions transmitter. Only displayed after the mempool’s first activation.
Implementations
Sourceimpl Mempool
impl Mempool
pub(crate) fn new( config: &Config, outbound: Buffer<BoxService<Request, Response, BoxError>, Request>, state: Buffer<BoxService<Request, Response, BoxError>, Request>, tx_verifier: Buffer<BoxService<Request, Response, TransactionError>, Request>, sync_status: SyncStatus, latest_chain_tip: LatestChainTip, chain_tip_change: ChainTipChange, misbehavior_sender: Sender<(PeerSocketAddr, u32)>, ) -> (Self, MempoolTxSubscriber)
Sourcefn is_enabled_by_debug(&self) -> bool
fn is_enabled_by_debug(&self) -> bool
Is the mempool enabled by a debug config option?
Sourcefn update_state(&mut self, tip_action: Option<&TipAction>) -> bool
fn update_state(&mut self, tip_action: Option<&TipAction>) -> bool
Update the mempool state (enabled / disabled) depending on how close to the tip is the synchronization, including side effects to state changes.
Accepts an optional TipAction for setting the last_seen_tip_hash field
when enabling the mempool state, it will not enable the mempool if this is None.
Returns true if the state changed.
Sourcepub fn is_enabled(&self) -> bool
pub fn is_enabled(&self) -> bool
Return whether the mempool is enabled or not.
Sourcefn remove_expired_from_peer_list(
send_to_peers_ids: &HashSet<UnminedTxId>,
expired_transactions: &HashSet<UnminedTxId>,
) -> HashSet<UnminedTxId>
fn remove_expired_from_peer_list( send_to_peers_ids: &HashSet<UnminedTxId>, expired_transactions: &HashSet<UnminedTxId>, ) -> HashSet<UnminedTxId>
Remove expired transaction ids from a given list of inserted ones.
Sourcefn update_metrics(&mut self)
fn update_metrics(&mut self)
Update metrics for the mempool.
Sourcefn disable_metrics(&self)
fn disable_metrics(&self)
Disable metrics for the mempool.